@@ -12,18 +12,26 @@ import socket
 import json
 import mimetypes
 from .socketutils import ServerSocket
-
+from .extensions import Protocol_HTTP
 
 class TCPServer:
     def __init__(self,host,port,blocking=True):
         self.server=ServerSocket(host,port)
+        self.blocking=blocking
+        self.host=host
+        self.port=port
+        self.extensions=[]
         self.hooks={"handle":[self.hookcontroller,[self.handle]],
-                    "init":[self.hookcontroller,[self.listen]],
-                    "mainloop":[self.hookcontroller,[self.run]]}
-    def initialize(self):
-        self.callhook("init")
+                    "start":[self.hookcontroller,[self.listen]],
+                    "mainloop":[self.hookcontroller,[self.run]],
+                    "init":[self.hookcontroller,[self.inittasks]]}
+    def inittasks(self):
+        pass
     def listen(self,lst=5):
         self.server.listen(lst)
+    def addExtension(self,extensionobject):
+        self.extensions.append(extensionobject)
+        extensionobject.extend(self)
     def run(self):
         connection=self.server.wait_until_connection()
         self.callhook("handle",connection,connection.recieveall())
@@ -37,7 +45,8 @@ class TCPServer:
     def addhook(self,hook,controller=None):
         if controller==None:
             controller=self.hookcontroller
-        self.hooks[hook]=[controller,[]]
+        if not hook in self.hooks:
+            self.hooks[hook]=[controller,[]]
     def addExtension(self,extension):
         self.addhookfunct("mainloop",extension.run)
     def delhook(self,hook):
@@ -50,6 +59,6 @@ class TCPServer:
     def handle(self,connection,data):
         print("HandleHook Called")
     def start(self):
-        self.callhook("init")
+        self.callhook("start")
         while 1:
             self.callhook("mainloop")
